
'use strict';

let assert = require('chai').assert;
let config = require('..');
let path = require('path');

let fixture = path.resolve.bind(path, __dirname, 'fixtures');

describe('mako-config', function () {
  it('should resolve entries relative to the config file', function () {
    return config(fixture('simple/mako.json')).then(function (config) {
      assert.deepEqual(config.entries, [ fixture('simple/index.html') ]);
    });
  });

  it('should resolve entries from glob patterns', function () {
    return config(fixture('glob/mako.json')).then(function (config) {
      assert.deepEqual(config.entries, [
        fixture('glob/a.txt'),
        fixture('glob/b.txt'),
        fixture('glob/c.txt')
      ]);
    });
  });

  it('should prune out entries that do not exist', function () {
    return config(fixture('missing-entry/mako.json')).then(function (config) {
      assert.deepEqual(config.entries, []);
    });
  });

  it('should allow the list of entries to be pre-empted', function () {
    return config(fixture('alternate-entries/mako.json'), [ 'index.md' ]).then(function (config) {
      assert.deepEqual(config.entries, [ fixture('alternate-entries/index.md') ]);
    });
  });

  it('should include an empty array of plugins if not specified', function () {
    return config(fixture('simple/mako.json')).then(function (config) {
      assert.deepEqual(config.plugins, []);
    });
  });

  it('should resolve plugins', function () {
    return config(fixture('plugin/mako.json')).then(function (config) {
      assert.deepEqual(config.plugins, [ 'vendor', 'local' ]);
    });
  });

  it('should pass arguments to plugins', function () {
    return config(fixture('plugin-options/mako.json')).then(function (config) {
      assert.deepEqual(config.plugins, [
        [ 'local', 'a', 'b', 'c' ]
      ]);
    });
  });
});
